@@ -89,7 +89,7 @@ int main(int argc, char* argv[])
     // see if we are starting with session management
     if (app.isSessionRestored())
     {
-        RESTORE(KompareShell)
+        kRestoreMainWindows<KompareShell>();
     }
     else
     {
